@@ -16,9 +16,10 @@
 #ifndef focus_h_
 #define focus_h_
 
+//#include <linux/slab.h>
 #include "encoder.h"
 //#include "xboxfb.h"
 
 int focus_calc_mode(xbox_video_mode * mode, struct riva_regs * riva_out );
-int focus_calc_hdtv_mode(xbox_hdtv_mode hdtv_mode, unsigned char pll_int, unsigned char * mode_out);
+int focus_calc_hdtv_mode(xbox_hdtv_mode hdtv_mode, unsigned char pll_int, void **encoder_regs);
 #endif
