@@ -4,10 +4,10 @@
 /////////////////////////////////
 // some typedefs to make for easy sizing
 
-typedef unsigned long ULONG;
-typedef unsigned int DWORD;
-typedef unsigned short WORD;
-typedef unsigned char BYTE;
+//typedef unsigned long ULONG;
+typedef unsigned int u32;
+typedef unsigned short u16;
+typedef unsigned char u8;
 #ifndef bool_already_defined_
 	typedef int bool;
 #endif
